@@ -7,7 +7,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -39,6 +39,6 @@ function(x) {
   NC <- x[1]
   NR <- x[2]
   x <- x[-c(1:2)]
-  .xts(apply(matrix(x[-(1:NR)], nc=NC),2,cumsum), cumsum(x[1:NR]))
+  .xts(apply(matrix(x[-(1:NR)], ncol=NC),2,cumsum), cumsum(x[1:NR]))
 }
 
